@@ -19,15 +19,19 @@ from requests import get as req_get
 
 
 class Bar:
-    def __init__(self, length: int = 0):
+    def __init__(self, length: int = 0, *, message: str = ""):
         self.length: int = length
         self.level: int = 0
+        self.message_: str = ""
 
         print(f"[{' ' * self.length}]", end="\b" * (self.length + 1), flush=True)
 
+        self.message(message) if message else None
+
     def clear(self):
         print("\b \b" * self.level, end="", flush=True)
         self.level = 0
+        self.message_ = ""
 
     def delete(self):
         self.clear()
@@ -38,6 +42,8 @@ class Bar:
         print()
 
     def update(self, total: int, current: int):
+        self.clear() if self.message_ else None
+
         if (new_level := int((current / total) * self.length)) == self.level:
             return
 
@@ -47,7 +53,9 @@ class Bar:
 
     def message(self, message: str):
         self.clear()
-        print(f"{message[:self.length]:^{self.length}}", end="", flush=True)
+        self.level = len(message := f"{(message[:self.length]):^{self.length}}")
+        print(message, end="", flush=True)
+        self.message_: str = message
 
 
 def check_process(process: str) -> int:
@@ -208,5 +216,5 @@ def print_users(users: List[Dict[str, str]]):
 
     print(f"{'Username':^{space_name}} | {'Folders':^{space_folders}}")
     for user in sorted(users, key=lambda usr: usr["USERNAME"].lower()):
-        folders_min: str = ",".join(set(map(lambda f: f[0], user["FOLDERS"])))
+        folders_min: str = ",".join(set(map(lambda f: f[0], user["FOLDERS"].split(","))))
         print(f"{user['USERNAME'][:space_name]:<{space_name}} | {folders_min:^{space_folders}}")
