@@ -125,32 +125,33 @@ def help_(comm: str = "", op: str = "", *_rest) -> str:
         "help": help_,
         "init": init,
         "config": config,
-        "config_list": config_list,
-        "config_cookies": config_cookies,
-        "config_files-folder": config_files_folder,
+        "config list": config_list,
+        "config cookies": config_cookies,
+        "config files-folder": config_files_folder,
         "download": download,
-        "download_users": download_users,
-        "download_update": download_update,
-        "download_submissions": download_submissions,
-        "download_journals": download_journals,
+        "download users": download_users,
+        "download update": download_update,
+        "download submissions": download_submissions,
+        "download journals": download_journals,
         "database": database,
-        "database_info": database_info,
-        "database_history": database_history,
-        "database_search-users": database_search_users,
-        "database_search-submissions": database_search_submissions,
-        "database_search-journals": database_search_journals,
-        "database_add-submission": database_add_submission,
-        "database_add-journal": database_add_journal,
-        "database_remove-users": database_remove_users,
-        "database_remove-submissions": database_remove_submissions,
-        "database_remove-journals": database_remove_journals,
-        "database_server": database_server,
-        "database_merge": database_merge,
-        "database_clean": database_clean,
-    }.get(f"{comm}_{op}" if op else comm, None)
+        "database info": database_info,
+        "database history": database_history,
+        "database search-users": database_search_users,
+        "database search-submissions": database_search_submissions,
+        "database search-journals": database_search_journals,
+        "database add-submission": database_add_submission,
+        "database add-journal": database_add_journal,
+        "database add-user": database_add_user,
+        "database remove-users": database_remove_users,
+        "database remove-submissions": database_remove_submissions,
+        "database remove-journals": database_remove_journals,
+        "database server": database_server,
+        "database merge": database_merge,
+        "database clean": database_clean,
+    }.get(comm := f"{comm} {op}".strip(), None)
 
     if f is None:
-        raise UnknownCommand(f"{comm} {op}".strip())
+        raise UnknownCommand(comm)
 
     return cleandoc(f.__doc__)
 
@@ -288,8 +289,7 @@ def download_users(db: FADatabase, *args: str):
     if len(args) != 2:
         raise MalformedCommand("users needs two arguments")
 
-    users_tmp: List[str] = list(
-        filter(bool, map(clean_username, args[0].split(","))))
+    users_tmp: List[str] = list(filter(bool, map(clean_username, args[0].split(","))))
     users: List[str] = sorted(set(users_tmp), key=users_tmp.index)
     folders_tmp: List[str] = list(filter(bool, map(str.strip, args[1].split(","))))
     folders: List[str] = sorted(set(folders_tmp), key=folders_tmp.index)
@@ -299,14 +299,16 @@ def download_users(db: FADatabase, *args: str):
 def download_update(db: FADatabase, *args: str):
     """
     USAGE
-        falocalrepo download update [stop=<stop n>] [<user1>,...,<userN>]
-                    [<folder1>,...,<folderN>]
+        falocalrepo download update [stop=<stop n>] [deactivated=<deactivated>]
+                    [<user1>,...,<userN>] [<folder1>,...,<folderN>]
 
     ARGUMENTS
-        <stop n>    Number of submissions to find in database before stopping,
-                    defaults to 1
-        <user>      Username
-        <folder>    One of gallery, scraps, favorites, journals
+        <stop n>       Number of submissions to find in database before stopping,
+                       defaults to 1
+        <deactivated>  Set to 'true' to check previously deactivated users, other
+                       values are ignored
+        <user>         Username
+        <folder>       One of gallery, scraps, favorites, journals
 
     DESCRIPTION
         Update the repository by checking the previously downloaded folders
@@ -316,12 +318,12 @@ def download_update(db: FADatabase, *args: str):
         skip users, use '@' as argument. The 'stop=<n>' option allows to stop
         updating after finding n submissions in a user's database entry, defaults
         to 1. If a user is deactivated, the folders in the database will be
-        prepended with a '!' and the user will be skipped when update is called
-        again.
+        prepended with a '!'. Deactivated users will be skipped when update is
+        called, unless the '<deactivated>' option is set to 'true'.
 
     EXAMPLES
         falocalrepo download update stop=5
-        falocalrepo download update @ gallery,scraps
+        falocalrepo download update deactivated=true @ gallery,scraps
         falocalrepo download update tom,jerry
     """
 
@@ -329,14 +331,12 @@ def download_update(db: FADatabase, *args: str):
     folders: List[str] = []
     opts, args = parse_args(args)
     if args and args[0] != "@":
-        users_tmp: List[str] = list(
-            filter(bool, map(clean_username, args[0].split(","))))
+        users_tmp: List[str] = list(filter(bool, map(clean_username, args[0].split(","))))
         users = sorted(set(users_tmp), key=users_tmp.index)
     if args[1:] and args[1] != "@":
-        folders_tmp: List[str] = list(
-            filter(bool, map(str.strip, args[1].split(","))))
+        folders_tmp: List[str] = list(filter(bool, map(str.strip, args[1].split(","))))
         folders = sorted(set(folders_tmp), key=folders_tmp.index)
-    download_users_update(db, users, folders, int(opts.get("stop", 1)))
+    download_users_update(db, users, folders, int(opts.get("stop", 1)), opts.get("deactivated", "").lower() == "true")
 
 
 def download_submissions(db: FADatabase, *args: str):
@@ -349,7 +349,7 @@ def download_submissions(db: FADatabase, *args: str):
 
     DESCRIPTION
         Download specific submissions. Requires submission ID's provided as separate
-        arguments.
+        arguments. If the submission is already in the database it is ignored.
 
     EXAMPLES
         falocalrepo download submissions 12345678 13572468 87651234
@@ -372,7 +372,7 @@ def download_journals(db: FADatabase, *args: str):
 
     DESCRIPTION
         Download specific journals. Requires journal ID's provided as separate
-        arguments.
+        arguments. If the journal is already in the database it is ignored.
 
     EXAMPLES
         falocalrepo download journals 123456 135724 876512
