@@ -19,6 +19,7 @@ from faapi import ParsingError
 from faapi import Submission
 from faapi import SubmissionPartial
 from falocalrepo_database import FADatabase
+from urllib3.exceptions import IncompleteRead
 
 from .commands import Bar
 from .commands import clean_string
@@ -83,6 +84,9 @@ def download_submission_file(api: FAAPI, sub_file_url: str, speed: int = 100) ->
                     bar.update(size, len(file_binary)) if size else None
                     sleep(1 / speed) if speed > 0 else None
 
+            if size and (l := len(file_binary)) != size:
+                raise IncompleteRead(l, size - l)
+
             bar.update(1, 1)
     except KeyboardInterrupt:
         print("\b\b  \b\b", end="")
@@ -101,6 +105,9 @@ def download_submission_file(api: FAAPI, sub_file_url: str, speed: int = 100) ->
 
 def download_submission(api: FAAPI, db: FADatabase, sub_id: int, user_update: bool = False) -> bool:
     try:
+        if sub_id in db.submissions:
+            Bar(length=10, message="IS IN DB").close()
+            return True
         sub: Submission = api.get_submission(sub_id, False)[0]
         sub_file: Optional[bytes] = download_submission_file(api, sub.file_url)
         save_submission(db, sub, sub_file, user_update)
@@ -119,6 +126,9 @@ def save_journal(db: FADatabase, journal: Journal, user_update: bool = False):
 
 
 def download_journal(api: FAAPI, db: FADatabase, jrn_id: int):
+    if jrn_id in db.journals:
+        Bar(length=10, message="IS IN DB").close()
+        return True
     journal: Journal = api.get_journal(jrn_id)
     save_journal(db, journal)
 
@@ -127,30 +137,31 @@ def download_journals(db: FADatabase, jrn_ids: List[str]):
     download_items(db, jrn_ids, download_journal)
 
 
-def download_users_update(db: FADatabase, users: List[str], folders: List[str], stop: int = 1):
+def download_users_update(db: FADatabase, users: List[str], folders: List[str], stop: int = 1, deactivated: bool = False):
     api: Optional[FAAPI] = None
     tot, fail = 0, 0
 
-    users = list(set(map(clean_username, users)))
+    users = list(map(clean_username, users))
+    users = sorted(set(users), key=users.index)
     users_db: List[dict] = sorted(
-        filter(lambda u: u["USERNAME"] in users, db.users),
-        key=lambda u: users.index(u["USERNAME"]))
+        filter(lambda u: not users or u["USERNAME"] in users, db.users),
+        key=lambda u: users.index(u["USERNAME"]) if users else u["USERNAME"])
 
     for user, user_folders in ((u["USERNAME"], u["FOLDERS"].split(",")) for u in users_db):
-        if any(folder.startswith("!") for folder in user_folders):
-            print(f"User {user} disabled")
+        if not (user_folders := [f for f in folders if f in user_folders] if folders else user_folders):
             continue
-        elif not (user_folders := [f for f in folders if f in user_folders] if folders else user_folders):
+        elif not deactivated and any(folder.startswith("!") for folder in user_folders):
+            print(f"User {user} deactivated")
             continue
         try:
             api = load_api(db) if api is None else api
             for folder in user_folders:
                 print(f"Updating: {user}/{folder}")
-                tot_, fail_ = download_user(api, db, user, folder, stop)
+                tot_, fail_ = download_user(api, db, user, folder.strip("!"), stop)
                 tot += tot_
                 fail += fail_
         except DisabledAccount:
-            print(f"User {user} disabled")
+            print(f"User {user} deactivated")
             db.users.disable_user(user)
             db.commit()
         except NoticeMessage:
@@ -165,7 +176,8 @@ def download_users_update(db: FADatabase, users: List[str], folders: List[str],
 
 def download_users(db: FADatabase, users: List[str], folders: List[str]):
     api: Optional[FAAPI] = None
-    for user in users:
+    users = list(map(clean_username, users))
+    for user in sorted(set(users), key=users.index):
         user_is_new: bool = user not in db.users
         try:
             api = load_api(db) if api is None else api
@@ -203,7 +215,7 @@ def download_user(api: FAAPI, db: FADatabase, user: str, folder: str, stop: int
     exists: Callable[[int], Optional[dict]]
 
     if folder.startswith("!"):
-        print(f"{user}/{folder} disabled")
+        print(f"{user}/{folder} deactivated")
         return 0, 0
     elif folder in ("gallery", "list-gallery"):
         download = api.gallery
@@ -246,21 +258,21 @@ def download_user(api: FAAPI, db: FADatabase, user: str, folder: str, stop: int
                 items_failed += 1
                 bar.message("ID ERROR")
                 bar.close()
-            elif item_ := exists(item.id):
-                bar.message("IS IN DB")
+                continue
+            bar.message("SEARCH DB")
+            if item_ := exists(item.id):
                 if folder == "favorites":
-                    found_items += db.submissions.add_favorite(item.id, user)
-                    db.commit()
-                else:
+                    found_items += not db.submissions.add_favorite(item.id, user)
+                elif folder in ("gallery", "scraps"):
+                    db.submissions.update({"USERUPDATE": 1}, item.id) if not item_["USERUPDATE"] else None
+                    found_items += not db.submissions.set_folder(item.id, folder) and item_["USERUPDATE"]
+                elif folder == "journals":
+                    db.journals.update({"USERUPDATE": 1}, item.id) if not item_["USERUPDATE"] else None
                     found_items += item_["USERUPDATE"]
-                    if folder in ("gallery", "scraps"):
-                        db.submissions.update({"USERUPDATE": 1}, item.id)
-                        db.submissions.set_folder(item.id, folder)
-                    elif folder == "journals":
-                        db.journals.update({"USERUPDATE": 1}, item.id)
-                    db.commit()
+                db.commit()
+                bar.message("IS IN DB")
                 if stop and found_items >= stop:
-                    print("\r" + (" " * (space_term - 1)), end="\r", flush=True)
+                    print("\r" + (" " * (space_term - 1)), end="\r", flush=True) if stop < 2 else bar.close()
                     page = 0
                     break
                 bar.close()
